function SS = AltruismExtrapolate(S)
% This function does "consumption extrapolation" for the altruistic model:
% Assuming that consumption is linear (or the desired consumption for the
% other agent), obtain derivatives of the value function outside the grid 
% use these for extrapolation.

nGridVec = S(1).nGridVec;       % read out stuff from object
FullInd  = S(1).FullInd;
g        = S(1).params.g;
J        = S(1).V.jac;

for i=1:2                       % loop over first and second dimensions
    indN     = FullInd;  indN{i}     = nGridVec(i);    % indeces of hightest
                                % grid point in dimension i.
    indNmin1 = FullInd;  indNmin1{i} = nGridVec(i)-1;  % same for one below
    indNmin2 = FullInd;  indNmin2{i} = nGridVec(i)-2;  % two below,
    indNplus1= FullInd;  indNplus1{i}= nGridVec(i)+1;  % and one above (extrapolation)

    dkN     = S(i).dx(indN{:}    ,ones(1,2) );  % distance from Nth to (N+1)th
                                 % grid point in dimension i. Expand for
                                 % the two players.
    dkcN    = S(i).dxc(indN{:}   ,ones(1,2) );  % centered diff. at N
    dkcNmin1= S(i).dxc(indNmin1{:},ones(1,2));  % centered diff. at N
    
    cN1 = J(indNmin1{:},:,i).^(-1/g);           % get implied consumption on
    cN2 = J(indNmin2{:},:,i).^(-1/g);           % (N-1)th and (N-2)th grid point
    cN  = cN1 + (cN1-cN2) .*  dkcN./ dkcNmin1;  % extrapolate consumption
    JN = cN .^ (-g);                            % back out V_k
    S(1).V.jac(indN{:},:,i) = JN;               % put V_k into Jacobian
    S(1).V.val(indNplus1{:},:) = S(1).V.val(indN{:},:) + JN .* dkN ;
end                             % Then extrapolate value function

SS = S;                         % hand over the edited object.
