function V = AltruismVFinalT(S)
% Obtains value-function in last period in finite-horizon model for
% object S with altruism model. 

params = S(1).params;           % read out parameters
a = params.a;  ap = params.ap;  gamma = params.g; 

if gamma==1                     % define utility function handle
    u = @(c)log(c);
else
    u = @(c)c.^(1-gamma)./(1-gamma);
end

nDim = S(1).nDim;
dt   = S(1).options.dt;

kgrid  = S(1).xGrid;            % read out wealth...
kpgrid = S(2).xGrid;
ygrid  = S(3).xGrid;            % ...and income of agents.
ypgrid = S(4).xGrid;

res  = kgrid + ygrid *dt;       % get his and her resources at t=T-dt
resp = kpgrid+ ypgrid*dt;
Res  = res + resp;              % get total resources of both
P    = res ./ Res;              % her share of total resources

ag = a^(1/gamma);
HisMinShare = ag/(1+ag);        % his minimal and her maximal share of
HerMaxShare = 1 /(1+ag);        % total resources implied by her a.

apg= ap^(1/gamma);
HerMinShare = apg/(1+apg);      % Bounds implied by his a'
HisMaxShare = 1  /(1+apg);

% Assign share of total consumption as linear in P, ranging from the
% minimal to the maximal share:
HerShare = (1-P).*HerMinShare +   P  .*HerMaxShare;
HisShare =   P  .*HisMinShare + (1-P).*HisMaxShare;

c  = HerShare.*Res / dt;        % get consumption rates over last interval
cp = HisShare.*Res / dt;        % (of length dt)

VT = (u(c) + a *u(cp))*dt;      % get his and her value function
VpT= (u(cp)+ ap*u(c) )*dt;
V = cat(nDim+1,VT,VpT);         % put together and return
