function V = AltruismVGuess(S)
% Obtains value-function guess for object S with altruism model. 

params = S(1).params;       % read out parameters
a = params.a;  ap = params.ap;  g = params.g;  rho = params.rho;
r = params.r;

nDim = S(1).nDim;

kgrid  = S(1).xGrid;
kpgrid = S(2).xGrid;
kup = kgrid(end,1,1,1);

my  = mean( S(3).GridVec ); % get mean income stream for each player
myp = mean( S(4).GridVec );

u = @(c) c.^(1-g) / (1-g);  % set up function handle for utility
Du = @(c)c.^(-g);           % function handle for marginal utility

% Guess consumption when one player is very rich as consumption
% from the modified Merton problem plus work income, which should
% be small for large assets.
FamilyNPV = kup + (my+myp)/r;   % net present value of family if they 
                                % received the mean income forever.
                                % ??? CONTINUE HERE!
% When he is broke:
%cK0  = my  +  kup * ( rho - (1-g)*r ) / g / ( 1+a^(1/g) );
%cpK0 = myp +  a^(1/g) * cK0;
cK0   = FamilyNPV * ( rho - (1-g)*r ) / g / ( 1+a^(1/g) );
                                % what she would consume out FamilyNPV in
                                % deterministic setting.
cpK0  = max( myp, a^(1/g) * cK0 );
                                % what she would give to him, or his mean
                                % income, which ever is higher
% When she is broke, do the same for her:
% cp0K = myp +  kup * ( rho - (1-g)*r ) / g / ( 1+ap^(1/g) );
% c0K  = my  +  ap^(1/g) * cp0K;
cp0K  = FamilyNPV * ( rho - (1-g)*r ) / g / ( 1+ap^(1/g) );
c0K   = max(  my, ap^(1/g) * cp0K);
% If both are broke:
if Du(my) > a*Du(myp)       % if she does not want to transfer at (0,0):
   if Du(myp) > ap*Du(my)   % if he doesn't want to either:
       c00  = my;           % set consumption equal to income stream
       cp00 = myp;
   else
       cp00  = (my+myp) / (1+ap^(1/g) ) ;     %If he transfers: fulfill FOC
       c00   = (my+myp) - cp00;               %for transfer
   end
else                        % if she wants to transfer at (0,0)
   c00  = (my+myp) / (1+a^(1/g) ) ; %fulfill her FOC for transfer
   cp00 = (my+myp) - c00;
end


cguess  = c00  + (cK0 -c00 )*kgrid./kup + (c0K-c00)*kpgrid./kup;
cpguess = cp00 + (cpK0-cp00)*kgrid./kup+ (cp0K-cp00)*kpgrid./kup;
                            % Consumption guess: linearly interpolate betw.
                            % the three consumption levels we guessed
                            % as guess for V (he is broke, she is broke, both are broke),
U = u(cguess)/rho;          % let them eat what we got above for all time
Up= u(cpguess)/rho;         
VGuess = U  + a*Up;
VpGuess = Up + ap*U;        %include altruism here
V = cat(nDim+1,VGuess,VpGuess);


% Another guesses we used:
% c = (r+rho)*kk  + (1+rho)*yy ;        % consume (r+rho) of current
%                                       % capital and (1+rho) of labor
%                                       % income
% Ind1Broke = FullInd;  Ind1Broke{1} = 1;
% c(Ind1Broke{:}) = yy(Ind1Broke{:});
% S(1).a = r*kk  + yy  - c ;            % adjust when broke
% 
% cp= (r+rho)*kkp + (1+rho)*yyp;        % Same for player 2
% Ind2Broke = FullInd;  Ind2Broke{2} = 1;
% cp(Ind2Broke{:}) = yyp(Ind2Broke{:});
% S(2).a = r*kkp + yyp - cp;
% 
% S = GetHamMatrix(S);               % Get Hamiltonian matrix
% S(1).FU(FullInd{:},1) = u(c ) + a *u(cp);  % Set flow utility
% S(1).FU(FullInd{:},2) = u(cp) + ap*u(c );
% HH = rho*speye( S(1).nSts ) - S(1).K; % Get value of playing these policies
% FUvec = reshape( S(1).FU, [S(1).nSts  S(1).nPlr] ); % forever
% VguessVec = HH \ FUvec;               
% Vguess    = reshape(VguessVec,[S(1).nGridVec' S(1).nPlr]);

