function AltruismVisualizeVFI(iter,S,distArray)
% Visualizes progress made in value-function iteration in altruism model:
% Consumption policy, risk-lovingness and distance between value-function
% updates.
%
% Input:
% iter:         scalar. number of iteration.
% S:            object. finite-element object.
% distArray:    nGrid1 x .. x nGridN x nPlr of distance of value function
%               from current iteration to last one.
% 
% Output:
% None.
%
% Called by:
% ValueFctIter.m

VisEvery=31;                % Visualize every ... iterations
yind    = 1;                % index on player 1's income grid for which to visualize
ypind   = 1;                % index on player 2's income grid for which to visualize
iPlr    = 1;                % player for which distances are shown

Ntop = round( S(1).nGrid/2 );

if mod(iter,VisEvery)==0    % Only refresh every ... iterations
    if iter==VisEvery       % Set up new figure when plotting first time
       figure; 
    end
    subplot(2,2,1)          % plot consumption
    surf( S(1).cons(:,:,yind,ypind) ), title('Her consumption (low y)')
    subplot(2,2,2)          % plot risk-lovingness
    pcolor(1*S(1).RiskLov(:,:,yind,ypind)); title('Her risk-aversion (low y)')
    subplot(2,2,3)          % plot distance to last value function
    surf( distArray(:,:,yind,ypind,iPlr) ); title('Value function: Distance')
    subplot(2,2,4)
    muProp = (S(1).V.jac(:,:,:,:,1,2) - S(1).V.jac(:,:,:,:,1,1) ) ./ S(1).V.jac(:,:,:,:,1,1);
    surf(muProp(1:Ntop,1:Ntop,1,1)')   % plot transfer motive: surface
    title('Her transfer motive'), zlim([-1 0])
    legend
    
    getframe;               % get frames for movie: need to do that
end                         % to get refreshed image
