function out = GetDt(K,pmmin)
% For a "Hamiltonian matrix" K (generated by GetHamMatrix.m), get the time
% increment dt that makes the smallest probability of staying at the
% current grid point equal to pmmin.
% 
% Inputs:
% K:        nSt-by-nSt sparse matrix, generated by GetHamMatrix.m
% pmmin:    scalar, optional argument. If set 0, largest possible dt is
%           returned that preserves the stochastic interpretation of the
%           associated transition matrix I+K*dt.
% Output:
% dt:       scalar.
% 
% Usage:
% K  = GetHamMatrix(S);         % get "Hamiltonian matrix"
% dt = GetDt(K,0.4);            % get dt that makes lowest pm=0.4.
% Pdt = speye(nSt)+K*dt;        % get transition matrix over interval dt
% nnew = Pdt' * nold;           % map forward density

if nargin==1                    % Set pmmin to 0.6 if not specified by user.
    pmmin=0.6;                  % Like this, most of the probability mass 
end                             % stays in area.
kmmin = min(diag(K));           % Get lowest entry on diagonal of K.
dt = (pmmin-1)/kmmin;           % Calculate dt to make pm=pmmin for this
out = dt;                       % grid point and return it.
