function SS = GetJacCnt(S,PlrVec,DimVec)
% Using the upward derivatives in S(1).V.jac, obtain the centered
% derivatives in dimension in DimVec for the players in PlrVec and write
% them into S(1).V.JacCnt. Returns entire object S again.
% 
% Input:
% Object S with required fields:
%    V.jac:     ... x nPlr x nDim: Upward first derivative of value fct.
%    other:     see beginning of function where they are read out.
% PlrVec:       optional, vector. Players for which to give output. Default
%               is for all players.
% DimVec:       optional, vector. Dimension for which to give output.
%               Default is for all continuous dimensions. 
%
% Output:
% Object S with updated field S(1).V.JacCnt, an ... x nPlr x nDim array
% (same size as S(1).V.jac).

nDim    = S(1).nDim;            % read out fields from object
nPlr    = S(1).nPlr;
nGridVec= S(1).nGridVec;
FullInd = S(1).FullInd;
if nargin<3                     % if no dimensions specified:
    DimVec = 1:nDim;            % go over all dimensions
end
if nargin<2                     % if no players specified:
    PlrVec = 1:nPlr;            % go over all players
end

for i=DimVec                    % loop over continuous dimensions:
if S(i).discr==0                % create index of going one cell down.
    inddn = FullInd;  inddn{i}=[1  1:nGridVec(i)-1]; % take same cell for lowest cell
    for j=PlrVec                % loop over players
        jup = S(1).V.jac(FullInd{:},j,i);   % get up- and downward derivative
        jdn = jup(inddn{:});                % and average them
        S(1).V.JacCnt(FullInd{:},j,i) = 0.5*(jup+jdn);
    end
end
end

SS = S;                         % return object
