function SS = GetMoments(S)
% Gets moments of stationary density S(1).nStat for object S.
%
% Input:
% Object S, required fields:
%    S(1).nStat:        nGrid1 x ... x nGridN array. Stationary density.
%    S(1).nDim:         scalar. Number of dimensions of state space (normal,
%                       not extended)
%    S(1).nSts:         scalar. Number of grid points of (normal) state
%                       space.
%    S(i).xGrid:        nGrid1 x ... x nGridN array. Grid for dimension i,
%                       for i=1,...,nDim.
%
% Output:
% Object S, with updated field S(1).moments. Contains subfields:
%    S(1).moments.m:	1-by-k row vector. Means of distribution
%    S(1).moments.sd:	1-by-k row vector. Standard deviations
%    S(1).moments.v:	k-by-k matrix. Covariance matrix
%    S(1).moments.cc:	k-by-k matrix. Correlation coefficients
%
% Calls:
% GetMomentsProbDist.m
%
% Usage:
% S(1).nStat = GetStatDensity(S);
% S = GetMoments(S);
% S(1).moments.cc                   % show matrix with correlation coeff.

nDim = S(1).nDim;                   
nSts = S(1).nSts;                   % read out fields from S
nStat = S(1).nStat(:);

X = zeros(nSts,nDim);               % fill matrix X with vectorized 
for i=1:nDim                        % random variables (each state)
    X(:,i) = S(i).xGrid(:);
end

S(1).moments = GetMomentsProbDist(X,nStat); % Get moments

SS = S;                             % return S
