function out = GetUpWindDer(f,S,dim)
% This function obtains the upwind derivative of function f in dimension
% dim. The drift in dimension dim is found in S(dim).a of finite-element
% object S.
%
% Input:
% f:     N1 x N2 x ... Ndim array containing the function to be
%        differentiated.
% dim:   scalar. dimension in which to differentiate
% S:     finite-element object. Necessary fields:
%   FullInd: cell of size Ndim. Contains full set of indeces for state
%        space.
%   a:   N1 x N2 x ... Ndim array with drift in dimension i.
%   dx:  N1 x N2 x ... Ndim array with differences between grid points in
%        dimension dim.  
%
% Output:
% N1 x N2 x ... Ndim array.

FullInd = S(1).FullInd;                     % Read out full set of indeces
N = S(dim).nGrid;                           % and size of grid in dimension dim.

MidInd  = FullInd;  MidInd{dim}  = 2:N-1;
GoUp = (S(dim).a(MidInd{:}) > 0);           % See if drift is upward-pointing
                                            % in dimension 'dim'.
DiffInd = FullInd;  DiffInd{dim} = 1:N-1;   % Get derivative of function f.  
fi = diff(f,1,dim)./S(dim).dx(DiffInd{:});

DnInd= FullInd;  DnInd{dim}=1:N-2;          % For grid points 2 to N-1, get
UpInd= FullInd;  UpInd{dim}=2:N-1;          % upwind derivative.
fiuw = GoUp.*fi(UpInd{:}) + ~GoUp.*fi(DnInd{:});

Ind1  = FullInd;  Ind1{dim}  =1;            % For 1st grid point, take upward
EndInd= FullInd;  EndInd{dim}=N-1;          % derivative, for Nth grid point
                                            % downward derivative.
out  = cat(dim,fi(Ind1{:}),fiuw,fi(EndInd{:})); 
                                            % return result
                                            