function res = GetMomentsProbDist(x,n)
% for a discrete probability distribution with values x and frequencies/
% probabilities/density n, the function returns the mean(s) and the variance
% (or covariance matrix) for the random variables in x.
%
% Input:
% x:    L-by-k matrix of k random variables with values for each of
%       the r.v.s in each columns. NaNs are not allowed.
% n:    L-by-1 column vector with frequencies.probabilites/density of the
%       random variable. Note: Need not sum up to 1 when a density,
%       function treats this.
% 
% Output: 
% A structure (res) with fields
% m:	mean of distribution 1-by-k row vector
% sd:	standard deviation of distribution(s): 1-by-k vector
% v:	k-by-k covariance matrix
% cc:	k-by-k matrix with correlation coefficients

[L, k] = size(x);       % read out size
nn = n/sum(n);          % normalize n to sum up to 1.
nn = nn(:,ones(1,k));	% bring n to size of nn for element-by-
                        % element multiplication
                        

m  = sum( nn.*x );	    % get row-vector of means
mm = m(ones(L,1),:);	% bring means in dimension of x to
                        % subtract mean from each entry in x
d  = x-mm;              % get deviations from means
v  = (nn.*d)' * d;	    % get covariance matrix
sd = sqrt(diag(v))';	% get st.dev.
cc = v ./ (sd'*sd);	    % get correlalation coefficients in
       	  		        % matrix

res.m  = m;		        % give back results in structure res
res.sd = sd;
res.v  = v;
res.cc =  cc;
