function qq = GetQuantProbDist(x,n,qtl)
% returns the quantiles qtl of a probability distribution that is given
% as a discrete approximation (e.g. from a discretized model, e.g. trino-
% mial trees). NOT EXACT FOR DISCRETE RANDOM VARIABLES.
%
% Inputs:
% x:    values the random variable takes, column vector
% n:    frequencies/probabilities, in same order as x, column vector
% qtl:  the desired quantiles, e.g. [.1 .25 .5 .75 .9]
%
% Output:
% vector of same length as qtl, containing the quantile values

NotNan = ~isnan(x) & ~isnan(n);     % only consider pairs where neither x
x = x(NotNan);                      % nor n is NaN
n = n(NotNan);

[xx, ind] = sort(x);        %sort values in x
nn = n(ind);                %sort frequencies in same pattern

NN = cumsum(nn);            %get cdf
OKind = NN(2:end)>NN(1:end-1); %sometimes, there are numbers so small that
OKind = logical( [1; OKind]);  %added to the one before, they still give
                               %the same number although they are different
                               %E.g.: (1+realmin>1) is false. Need to get
                               %rid of these for interpolation.  
                        
qq = interp1(NN(OKind),xx(OKind),qtl);    %interpolate to get quantiles