function ind = Multi2SinglInd(siz,MultiInd)
% For array of size 'siz', turns multiple indices (read: X(1,2)) into
% single indexing (read: X(3)).
%
% Input:
% siz:      1 x nDim row vector. Size of array with multiple dimensions.
% MultiInd: N x nDim matrix. Each row describes one element in the nDim-
%           dimensional space. N such elements (variable). Index: X(1,2);
%
% Output:
% N x 1 vector. (Single) index of the vectorized space. Index: X(3).
%
% Note: Comparable to Matlab function sub2ind, but takes in all indices at
% once and is faster.

CountUp = [1 cumprod(siz(1:end-1))];
ind = 1 + (MultiInd-1) * CountUp';