function SS = SetUpField(S,FieldName,StructInd,DefaultVal)
% Sets up field with name 'FieldName' in structure S at the index
% 'StructInd'. Creates field if it doesn't exist yet, puts 'DefaultVal' if
% field is still empty at index 'StructInd' and extends content to size of
% 'DefaultVal' if field content is a scalar.
%
% Input:
% S:            structure (may or may not contain a field named
%               "FieldName" at index "StructInd")
% FieldName:    string. Name of field to be created or filled in S.
% StructInd:    scalar: natural number. Index of structure where to fill
% DefaultVal:   Any array.
%
% Output:
% Modified structure SS (like S, but added or altered field 'FieldName').
% 
% Usage:
% S = SetUpField(S,'a',i,zeros(nGridVec'));
% % Set up field named 'a' in position i of structure with array of zeros:
% 
% Called by:
% FinElObjSetUp.m

if isfield(S,FieldName)                         % If field already exists:
    if isempty(S(StructInd).(FieldName))        % If empty:
        S(StructInd).(FieldName) = DefaultVal;  % put default value
    elseif length(S(StructInd).(FieldName)(:)) == 1 
        if S(1).nDim==1                         % If filled with scalar:
            S(StructInd).(FieldName) = ones(S(1).nGridVec,1)*S(StructInd).(FieldName);
        else                                    % Expand to size of default
            S(StructInd).(FieldName) = ones(S(1).nGridVec')*S(StructInd).(FieldName);
        end
    end                                         
else                                            % Set up field with default
    S(StructInd).(FieldName) = DefaultVal;      % value if field not there yet
end    
       
SS = S;                                         % return structure
